document.addEventListener('DOMContentLoaded', () => {
  const addButton = document.getElementById('addNew');
  const addForm = document.getElementById('addForm');
  const cancelButton = document.getElementById('cancelAdd');
  const websiteForm = document.getElementById('websiteForm');
  const websiteGrid = document.getElementById('websiteGrid');

  // Load saved websites from localStorage
  let websites = JSON.parse(localStorage.getItem('websites')) || [];

  // Show/hide form
  addButton.addEventListener('click', () => {
    addForm.classList.remove('hidden');
  });

  cancelButton.addEventListener('click', () => {
    addForm.classList.add('hidden');
    websiteForm.reset();
  });

  // Handle form submission
  websiteForm.addEventListener('submit', (e) => {
    e.preventDefault();

    const newWebsite = {
      url: document.getElementById('urlInput').value,
      title: document.getElementById('titleInput').value,
      description: document.getElementById('descInput').value,
      image: document.getElementById('imageInput').value,
      id: Date.now()
    };

    websites.push(newWebsite);
    localStorage.setItem('websites', JSON.stringify(websites));
    
    renderWebsites();
    websiteForm.reset();
    addForm.classList.add('hidden');
  });

  // Render websites
  function renderWebsites() {
    websiteGrid.innerHTML = websites.map(site => `
      <div class="card" data-id="${site.id}">
        <img src="${site.image}" alt="${site.title}" onerror="this.src='data:image/svg+xml,<svg xmlns=%22http://www.w3.org/2000/svg%22 width=%22100%22 height=%22100%22><rect width=%22100%22 height=%22100%22 fill=%22%23404040%22/><text x=%2250%%22 y=%2250%%22 dominant-baseline=%22middle%22 text-anchor=%22middle%22 fill=%22%23ffffff%22>No Image</text></svg>'">
        <div class="card-content">
          <h3><a href="${site.url}" target="_blank" rel="noopener noreferrer">${site.title}</a></h3>
          <p>${site.description}</p>
        </div>
      </div>
    `).join('');
  }

  // Initial render
  renderWebsites();
});
